StandardScaleParams

Struct StandardScaleParams 

pub struct StandardScaleParams {
    pub mean: f64,
    pub std_dev: f64,
}
Parameters for the standard scaler.

Fields

mean: f64

The mean of the data.

std_dev: f64

The standard deviation of the data.

Implementations

Source

impl StandardScaleParams

pub fn new(mean: f64, std_dev: f64) -> Self

Create a new StandardScaleParams with the given mean and standard deviation.

pub fn from_data<T>(data: T) -> Self
where T: Iterator<Item = f64>,

Create a new StandardScaleParams from the given data.

Note: this uses Welford’s online algorithm to compute mean and variance in a single pass, since we only have an iterator. The standard deviation is calculated using the biased estimator, for parity with the scikit-learn implementation.

pub fn from_data_ignoring_nans<T: Iterator<Item = f64>>(data: T) -> Self

Create a new StandardScaleParams from the given data, ignoring NaN values.

This is useful if you have NaN values in your data and want to avoid propagating them during the standardization process.

See StandardScaleParams::from_data for more details on the implementation.