pub struct MinMaxScaler { /* private fields */ }Expand description
A transformer that scales each item to a custom range, defaulting to [0, 1].
Implementations
Sourceimpl MinMaxScaler
impl MinMaxScaler
Sourcepub fn with_scaled_range(self, min: f64, max: f64) -> Self
pub fn with_scaled_range(self, min: f64, max: f64) -> Self
Set the output range for the transformation.
Sourcepub fn with_data_range(self, min: f64, max: f64) -> Self
pub fn with_data_range(self, min: f64, max: f64) -> Self
Manually set the input range for the transformation.
This is useful if you know the input range in advance and want to avoid the overhead of fitting the scaler to the data during the initial transform, and instead want to set the input range manually.
Note that this will override any previously set (or learned) parameters.